@@ -1,7 +1,7 @@
 package Data::Sah::Coerce;
 
-our $DATE = '2016-09-29'; # DATE
-our $VERSION = '0.020'; # VERSION
+our $DATE = '2017-03-14'; # DATE
+our $VERSION = '0.021'; # VERSION
 
 use 5.010001;
 use strict;
@@ -119,7 +119,7 @@ Data::Sah::Coerce - Coercion rules for Data::Sah
 
 =head1 VERSION
 
-This document describes version 0.020 of Data::Sah::Coerce (from Perl distribution Data-Sah-Coerce), released on 2016-09-29.
+This document describes version 0.021 of Data::Sah::Coerce (from Perl distribution Data-Sah-Coerce), released on 2017-03-14.
 
 =head1 SYNOPSIS
 
@@ -299,7 +299,11 @@ something like:
 =head1 FUNCTIONS
 
 
-=head2 gen_coercer() -> any
+=head2 gen_coercer
+
+Usage:
+
+ gen_coercer() -> any
 
 Generate coercer code.
 
@@ -349,7 +353,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
