@@ -1,7 +1,7 @@
 package Data::Sah::CoerceCommon;
 
-our $DATE = '2016-09-29'; # DATE
-our $VERSION = '0.020'; # VERSION
+our $DATE = '2017-03-14'; # DATE
+our $VERSION = '0.021'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -283,12 +283,16 @@ Data::Sah::CoerceCommon - Common stuffs for Data::Sah::Coerce and Data::Sah::Coe
 
 =head1 VERSION
 
-This document describes version 0.020 of Data::Sah::CoerceCommon (from Perl distribution Data-Sah-Coerce), released on 2016-09-29.
+This document describes version 0.021 of Data::Sah::CoerceCommon (from Perl distribution Data-Sah-Coerce), released on 2017-03-14.
 
 =head1 FUNCTIONS
 
 
-=head2 get_coerce_rules(%args) -> [status, msg, result, meta]
+=head2 get_coerce_rules
+
+Usage:
+
+ get_coerce_rules(%args) -> [status, msg, result, meta]
 
 Get coerce rules.
 
@@ -402,7 +406,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
